#[non_exhaustive]pub struct AndroidKeyRestrictions {
pub allowed_applications: Vec<AndroidApplication>,
/* private fields */
}Expand description
The Android apps that are allowed to use the key.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.allowed_applications: Vec<AndroidApplication>A list of Android applications that are allowed to make API calls with this key.
Implementations
Sourceimpl AndroidKeyRestrictions
impl AndroidKeyRestrictions
pub fn new() -> Self
Sourcepub fn set_allowed_applications<T, V>(self, v: T) -> Self
pub fn set_allowed_applications<T, V>(self, v: T) -> Self
Sets the value of allowed_applications.
Example
ⓘ
use google_cloud_apikeys_v2::model::AndroidApplication;
let x = AndroidKeyRestrictions::new()
.set_allowed_applications([
AndroidApplication::default()/* use setters */,
AndroidApplication::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for AndroidKeyRestrictions
impl Clone for AndroidKeyRestrictions
Sourcefn clone(&self) -> AndroidKeyRestrictions
fn clone(&self) -> AndroidKeyRestrictions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AndroidKeyRestrictions
impl Debug for AndroidKeyRestrictions
Sourceimpl Default for AndroidKeyRestrictions
impl Default for AndroidKeyRestrictions
Sourcefn default() -> AndroidKeyRestrictions
fn default() -> AndroidKeyRestrictions
Returns the “default value” for a type. Read more
Sourceimpl Message for AndroidKeyRestrictions
impl Message for AndroidKeyRestrictions
Sourceimpl PartialEq for AndroidKeyRestrictions
impl PartialEq for AndroidKeyRestrictions
impl StructuralPartialEq for AndroidKeyRestrictions