#[non_exhaustive]pub struct LookupKeyResponse {
pub parent: String,
pub name: String,
/* private fields */
}Expand description
Response message for LookupKey method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringThe project that owns the key with the value specified in the request.
name: StringThe resource name of the API key. If the API key has been purged, resource name is empty.
Implementations
Sourceimpl LookupKeyResponse
impl LookupKeyResponse