CreateKeyRequest

Struct CreateKeyRequest 

#[non_exhaustive]
pub struct CreateKeyRequest { pub parent: String, pub key: Option<Key>, pub key_id: String, /* private fields */ }
Request message for CreateKey method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The project in which the API key is created.

key: Option<Key>

Required. The API key fields to set at creation time. You can configure only the display_name, restrictions, and annotations fields.

key_id: String

User specified key id (optional). If specified, it will become the final component of the key resource name.

The id must be unique within the project, must conform with RFC-1034, is restricted to lower-cased letters, and has a maximum length of 63 characters. In another word, the id must match the regular expression: [a-z]([a-z0-9-]{0,61}[a-z0-9])?.

The id must NOT be a UUID-like string.

Implementations

Source

impl CreateKeyRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateKeyRequest::new().set_parent("example");
pub fn set_key<T>(self, v: T) -> Self
where T: Into<Key>,

Sets the value of key.

Example
use google_cloud_apikeys_v2::model::Key;
let x = CreateKeyRequest::new().set_key(Key::default()/* use setters */);
pub fn set_or_clear_key<T>(self, v: Option<T>) -> Self
where T: Into<Key>,

Sets or clears the value of key.

Example
use google_cloud_apikeys_v2::model::Key;
let x = CreateKeyRequest::new().set_or_clear_key(Some(Key::default()/* use setters */));
let x = CreateKeyRequest::new().set_or_clear_key(None::<Key>);
pub fn set_key_id<T: Into<String>>(self, v: T) -> Self

Sets the value of key_id.

Example
let x = CreateKeyRequest::new().set_key_id("example");