#[non_exhaustive]pub struct UpdateKeyRequest {
pub key: Option<Key>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for UpdateKey method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: Option<Key>Required. Set the name field to the resource name of the API key to be
updated. You can update only the display_name, restrictions, and
annotations fields.
update_mask: Option<FieldMask>The field mask specifies which fields to be updated as part of this
request. All other fields are ignored.
Mutable fields are: display_name, restrictions, and annotations.
If an update mask is not provided, the service treats it as an implied mask
equivalent to all allowed fields that are set on the wire. If the field
mask has a special value “*”, the service treats it equivalent to replace
all allowed mutable fields.
Implementations
Sourceimpl UpdateKeyRequest
impl UpdateKeyRequest
pub fn new() -> Self
Sourcepub fn set_or_clear_key<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_key<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateKeyRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateKeyRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateKeyRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateKeyRequest
impl Clone for UpdateKeyRequest
Sourcefn clone(&self) -> UpdateKeyRequest
fn clone(&self) -> UpdateKeyRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateKeyRequest
impl Debug for UpdateKeyRequest
Sourceimpl Default for UpdateKeyRequest
impl Default for UpdateKeyRequest
Sourcefn default() -> UpdateKeyRequest
fn default() -> UpdateKeyRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateKeyRequest
impl Message for UpdateKeyRequest
Sourceimpl PartialEq for UpdateKeyRequest
impl PartialEq for UpdateKeyRequest
impl StructuralPartialEq for UpdateKeyRequest